darkhistory.electrons — DarkHistory documentation

# darkhistory.electrons

Electron cooling processes.

Electrons cool via inverse Compton scattering (ICS), which is handled by the package `ics`. The full electron cooling calculation, including both ICS and atomic cooling, is done in `elec_cooling`.

Positrons ultimately annihilate with electrons after first forming positronium: the resulting spectrum is calculated in `positronium`.

Modules

`elec_cooling` | Function for calculating the electron cooling transfer function.
`positronium` | Positronium annihilation functions.

Packages

`ics` | Inverse Compton scattering modules.

#### Previous topic

darkhistory.utilities.Interpolator2D

#### Next topic

darkhistory.electrons.elec_cooling

### This Page

Show Source